if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database 1> /dev/null &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi

( cd opt/AutoScan/usr/lib ; rm -rf libpng12.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpng12.so.0 libpng12.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xevie.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so )
( cd opt/AutoScan/usr/lib ; rm -rf libatk-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libatk-1.0.so.0.901.0 libatk-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libdl.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libdl-2.4.so libdl.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_nis.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_nis-2.4.so libnss_nis.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xtest.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-sync.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libc.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libc-2.4.so libc.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-screensaver.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xinerama.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xv.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-shape.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so )
( cd opt/AutoScan/usr/lib ; rm -rf libcrypt.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libcrypt-2.4.so libcrypt.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libdbus-glib-1.so )
( cd opt/AutoScan/usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangox-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpangox-1.0.so.0.1400.9 libpangox-1.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libORBitCosNaming-2.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libORBitCosNaming-2.so.0.1.0 libORBitCosNaming-2.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xv.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xv.so.0.0.0 libxcb-xv.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgobject-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgobject-2.0.so.0.1200.9 libgobject-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libX11.so )
( cd opt/AutoScan/usr/lib ; ln -sf libX11.so.6.2.0 libX11.so )
( cd opt/AutoScan/usr/lib ; rm -rf libresolv.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libresolv-2.4.so libresolv.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb.so.1.0.0 libxcb.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xprint.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-shm.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libdbus-glib-1.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libdbus-glib-1.so.2.1.0 libdbus-glib-1.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libXau.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libXau.so.6.0.0 libXau.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libutil.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libutil-2.4.so libutil.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libfreetype.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libfreetype.so.6.3.13 libfreetype.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libxml2.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libxml2.so.2.6.27 libxml2.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_dns.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_dns-2.4.so libnss_dns.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libcairo.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libcairo.so.2.9.3 libcairo.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libfontconfig.so )
( cd opt/AutoScan/usr/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so )
( cd opt/AutoScan/usr/lib ; rm -rf libORBitCosNaming-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libORBitCosNaming-2.so.0.1.0 libORBitCosNaming-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf librt.so )
( cd opt/AutoScan/usr/lib ; ln -sf librt.so.1 librt.so )
( cd opt/AutoScan/usr/lib ; rm -rf libORBit-imodule-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libORBit-imodule-2.so.0.0.0 libORBit-imodule-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgtk-x11-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgtk-x11-2.0.so.0.1000.9 libgtk-x11-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-sync.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-sync.so.0.0.0 libxcb-sync.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgconf-2.so.4 )
( cd opt/AutoScan/usr/lib ; ln -sf libgconf-2.so.4.1.2 libgconf-2.so.4 )
( cd opt/AutoScan/usr/lib ; rm -rf libresolv.so )
( cd opt/AutoScan/usr/lib ; ln -sf libresolv.so.2 libresolv.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangoft2-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpangoft2-1.0.so.0.1400.9 libpangoft2-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk_pixbuf-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1000.9 libgdk_pixbuf-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libcairo.so )
( cd opt/AutoScan/usr/lib ; ln -sf libcairo.so.2.9.3 libcairo.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangoxft-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpangoxft-1.0.so.0.1400.9 libpangoxft-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libORBit-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libORBit-2.so.0.1.0 libORBit-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libXft.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libXft.so.2.1.2 libXft.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xlib.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xf86dri.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so )
( cd opt/AutoScan/usr/lib ; rm -rf libz.so )
( cd opt/AutoScan/usr/lib ; ln -sf libz.so.1.2.3 libz.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_compat.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_compat.so.2 libnss_compat.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgthread-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgthread-2.0.so.0.1200.9 libgthread-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libBrokenLocale.so )
( cd opt/AutoScan/usr/lib ; ln -sf libBrokenLocale.so.1 libBrokenLocale.so )
( cd opt/AutoScan/usr/lib ; rm -rf libBrokenLocale.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libBrokenLocale-2.4.so libBrokenLocale.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf ld-linux.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf ld-2.4.so ld-linux.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xvmc.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-composite.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-screensaver.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-screensaver.so.0.0.0 libxcb-screensaver.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgmodule-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgmodule-2.0.so.0.1200.9 libgmodule-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-glx.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libdl.so )
( cd opt/AutoScan/usr/lib ; ln -sf libdl.so.2 libdl.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-record.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgobject-2.0.so.0.1200.9 libgobject-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libanl.so )
( cd opt/AutoScan/usr/lib ; ln -sf libanl.so.1 libanl.so )
( cd opt/AutoScan/usr/lib ; rm -rf libXext.so )
( cd opt/AutoScan/usr/lib ; ln -sf libXext.so.6.4.0 libXext.so )
( cd opt/AutoScan/usr/lib ; rm -rf libanl.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libanl-2.4.so libanl.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-shape.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-shape.so.0.0.0 libxcb-shape.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libXft.so )
( cd opt/AutoScan/usr/lib ; ln -sf libXft.so.2.1.2 libXft.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpango-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpango-1.0.so.0.1400.9 libpango-1.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-dpms.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangoft2-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpangoft2-1.0.so.0.1400.9 libpangoft2-1.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnsl.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnsl.so.1 libnsl.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangocairo-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpangocairo-1.0.so.0.1400.9 libpangocairo-1.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libORBit-2.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libORBit-2.so.0.1.0 libORBit-2.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-damage.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libpthread.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpthread-2.4.so libpthread.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_nisplus.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_nisplus.so.2 libnss_nisplus.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xfixes.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_files.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_files.so.2 libnss_files.so )
( cd opt/AutoScan/usr/lib ; rm -rf libm.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libm-2.4.so libm.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xprint.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xprint.so.0.0.0 libxcb-xprint.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgmodule-2.0.so.0.1200.9 libgmodule-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xf86dri.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xf86dri.so.0.0.0 libxcb-xf86dri.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_files.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_files-2.4.so libnss_files.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libcrypt.so )
( cd opt/AutoScan/usr/lib ; ln -sf libcrypt.so.1 libcrypt.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpango-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpango-1.0.so.0.1400.9 libpango-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-composite.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-composite.so.0.0.0 libxcb-composite.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libXdmcp.so )
( cd opt/AutoScan/usr/lib ; ln -sf libXdmcp.so.6.0.0 libXdmcp.so )
( cd opt/AutoScan/usr/lib ; rm -rf libXdmcp.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libXdmcp.so.6.0.0 libXdmcp.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xevie.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xevie.so.0.0.0 libxcb-xevie.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libX11-xcb.so )
( cd opt/AutoScan/usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so )
( cd opt/AutoScan/usr/lib ; rm -rf libthread_db.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-dpms.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-dpms.so.0.0.0 libxcb-dpms.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libdbus-1.so.3 )
( cd opt/AutoScan/usr/lib ; ln -sf libdbus-1.so.3.2.0 libdbus-1.so.3 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-record.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-record.so.0.0.0 libxcb-record.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangox-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpangox-1.0.so.0.1400.9 libpangox-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libexpat.so )
( cd opt/AutoScan/usr/lib ; ln -sf libexpat.so.1.5.0 libexpat.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1000.9 libgdk_pixbuf_xlib-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangoxft-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpangoxft-1.0.so.0.1400.9 libpangoxft-1.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libz.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libfreetype.so )
( cd opt/AutoScan/usr/lib ; ln -sf libfreetype.so.6.3.13 libfreetype.so )
( cd opt/AutoScan/usr/lib ; rm -rf libvte.so.9 )
( cd opt/AutoScan/usr/lib ; ln -sf libvte.so.9.2.4 libvte.so.9 )
( cd opt/AutoScan/usr/lib ; rm -rf libX11-xcb.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libX11-xcb.so.1.0.0 libX11-xcb.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-randr.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk-x11-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk-x11-2.0.so.0.1000.9 libgdk-x11-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgnomevfs-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgnomevfs-2.so.0.1799.1 libgnomevfs-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libexpat.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libexpat.so.1.5.0 libexpat.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-glx.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-glx.so.0.0.0 libxcb-glx.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgthread-2.0.so.0.1200.9 libgthread-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-res.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xvmc.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xvmc.so.0.0.0 libxcb-xvmc.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libIDL-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libIDL-2.so.0.0.0 libIDL-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libXext.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libXext.so.6.4.0 libXext.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-res.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-res.so.0.0.0 libxcb-res.so )
( cd opt/AutoScan/usr/lib ; rm -rf libIDL-2.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libIDL-2.so.0.0.0 libIDL-2.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-shm.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-shm.so.0.0.0 libxcb-shm.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgtk-x11-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgtk-x11-2.0.so.0.1000.9 libgtk-x11-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-randr.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-randr.so.0.0.0 libxcb-randr.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libXau.so )
( cd opt/AutoScan/usr/lib ; ln -sf libXau.so.6.0.0 libXau.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xinerama.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xinerama.so.0.0.0 libxcb-xinerama.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libpng12.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpng12.so.0.1.2.8 libpng12.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xtest.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xtest.so.0.0.0 libxcb-xtest.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-render.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so )
( cd opt/AutoScan/usr/lib ; rm -rf libglib-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libglib-2.0.so.0.1200.9 libglib-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libORBit-imodule-2.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libORBit-imodule-2.so.0.0.0 libORBit-imodule-2.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libdbus-1.so )
( cd opt/AutoScan/usr/lib ; ln -sf libdbus-1.so.3.2.0 libdbus-1.so )
( cd opt/AutoScan/usr/lib ; rm -rf libvte.so )
( cd opt/AutoScan/usr/lib ; ln -sf libvte.so.9.2.4 libvte.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgconf-2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgconf-2.so.4.1.2 libgconf-2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_dns.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_dns.so.2 libnss_dns.so )
( cd opt/AutoScan/usr/lib ; rm -rf libX11.so.6 )
( cd opt/AutoScan/usr/lib ; ln -sf libX11.so.6.2.0 libX11.so.6 )
( cd opt/AutoScan/usr/lib ; rm -rf libthread_db.so )
( cd opt/AutoScan/usr/lib ; ln -sf libthread_db.so.1 libthread_db.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_nis.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_nis.so.2 libnss_nis.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xlib.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xlib.so.0.0.0 libxcb-xlib.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb.so.1.0.0 libxcb.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgnomevfs-2.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgnomevfs-2.so.0.1799.1 libgnomevfs-2.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libglib-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libglib-2.0.so.0.1200.9 libglib-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-render.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-render.so.0.0.0 libxcb-render.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_hesiod.so )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_hesiod.so.2 libnss_hesiod.so )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-damage.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-damage.so.0.0.0 libxcb-damage.so )
( cd opt/AutoScan/usr/lib ; rm -rf libutil.so )
( cd opt/AutoScan/usr/lib ; ln -sf libutil.so.1 libutil.so )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk-x11-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk-x11-2.0.so.0.1000.9 libgdk-x11-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk_pixbuf_xlib-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk_pixbuf_xlib-2.0.so.0.1000.9 libgdk_pixbuf_xlib-2.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libfontconfig.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libXrender.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libpng.so )
( cd opt/AutoScan/usr/lib ; ln -sf libpng.so.3 libpng.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_hesiod.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_hesiod-2.4.so libnss_hesiod.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libgdk_pixbuf-2.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libgdk_pixbuf-2.0.so.0.1000.9 libgdk_pixbuf-2.0.so )
( cd opt/AutoScan/usr/lib ; rm -rf librt.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf librt-2.4.so librt.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libXrender.so )
( cd opt/AutoScan/usr/lib ; ln -sf libXrender.so.1.3.0 libXrender.so )
( cd opt/AutoScan/usr/lib ; rm -rf libm.so )
( cd opt/AutoScan/usr/lib ; ln -sf libm.so.6 libm.so )
( cd opt/AutoScan/usr/lib ; rm -rf libpangocairo-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; ln -sf libpangocairo-1.0.so.0.1400.9 libpangocairo-1.0.so.0 )
( cd opt/AutoScan/usr/lib ; rm -rf libxcb-xfixes.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxcb-xfixes.so.0.0.0 libxcb-xfixes.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnsl.so.1 )
( cd opt/AutoScan/usr/lib ; ln -sf libnsl-2.4.so libnsl.so.1 )
( cd opt/AutoScan/usr/lib ; rm -rf libxml2.so )
( cd opt/AutoScan/usr/lib ; ln -sf libxml2.so.2.6.27 libxml2.so )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_nisplus.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_nisplus-2.4.so libnss_nisplus.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libnss_compat.so.2 )
( cd opt/AutoScan/usr/lib ; ln -sf libnss_compat-2.4.so libnss_compat.so.2 )
( cd opt/AutoScan/usr/lib ; rm -rf libpng.so.3 )
( cd opt/AutoScan/usr/lib ; ln -sf libpng.so.3.1.2.8 libpng.so.3 )
( cd opt/AutoScan/usr/lib ; rm -rf libatk-1.0.so )
( cd opt/AutoScan/usr/lib ; ln -sf libatk-1.0.so.0.901.0 libatk-1.0.so )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 50-user.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/50-user.conf 50-user.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 30-amt-aliases.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/30-amt-aliases.conf 30-amt-aliases.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 65-fonts-persian.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/65-fonts-persian.conf 65-fonts-persian.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 20-lohit-gujarati.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/20-lohit-gujarati.conf 20-lohit-gujarati.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 80-delicious.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 30-urw-aliases.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/30-urw-aliases.conf 30-urw-aliases.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 60-latin.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 51-local.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 40-generic.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/40-generic.conf 40-generic.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 20-fix-globaladvance.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/20-fix-globaladvance.conf 20-fix-globaladvance.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 69-unifont.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
( cd opt/AutoScan/usr/etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
( cd usr/bin ; rm -rf autoscan-network )
( cd usr/bin ; ln -sf /opt/AutoScan/bin/autoscan-network autoscan-network )
