#! /bin/sh


########
/opt/AutoScan/usr/bin/gconftool-2 --makefile-install-rule /opt/AutoScan/usr/share/apps/autoscan-network/autoscan-network.schemas
##########

########
chown root:root /opt/AutoScan/bin/autoscan-network-daemon ;chmod +s /opt/AutoScan/bin/autoscan-network-daemon
##########

########
/opt/AutoScan/usr/bin/fc-cache -fv
########


########
if [ -e "/usr/share/applications/"  ]; then
	echo "copy /usr/share/applications/autoscan-network.desktop"
	cp /opt/AutoScan/usr/share/applications/autoscan-network.desktop /usr/share/applications/
fi

if [ -e "/usr/lib/menu/"  ]; then
	echo "copy /usr/lib/menu/autoscan-network"
	cp /opt/AutoScan/usr/lib/menu/autoscan-network  /usr/lib/menu/
fi
