#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/opt/AutoScan/usr/lib"
XML2_LIBS="-lxml2 -lz   -lm "
XML2_INCLUDEDIR="-I/opt/AutoScan/usr/include/libxml2"
MODULE_VERSION="xml2-2.6.27"

